"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const getLastBuffers_1 = __importDefault(require("../../../src/functions/getLastBuffers"));
const generateTicker_1 = __importDefault(require("../../generators/generateTicker"));
describe('getLastBuffers', () => {
    it('should return the correct number of unique items', () => {
        const buffer = [
            (0, generateTicker_1.default)('A'),
            (0, generateTicker_1.default)('B'),
            (0, generateTicker_1.default)('C'),
            (0, generateTicker_1.default)('A'),
            (0, generateTicker_1.default)('D'),
        ];
        const maxNumResult = 3;
        const result = (0, getLastBuffers_1.default)(buffer, maxNumResult);
        expect(result.length).toBe(maxNumResult);
        expect(result.map(item => item.code)).toEqual(['D', 'A', 'C']);
    });
    it('should return an empty array if the input buffer is empty', () => {
        const buffer = [];
        const maxNumResult = 3;
        const result = (0, getLastBuffers_1.default)(buffer, maxNumResult);
        expect(result.length).toBe(0);
        expect(result).toEqual([]);
    });
    it('should return all unique items if maxNumResult is greater than the number of unique items', () => {
        const buffer = [
            (0, generateTicker_1.default)('A'),
            (0, generateTicker_1.default)('B'),
            (0, generateTicker_1.default)('C'),
            (0, generateTicker_1.default)('A'),
        ];
        const maxNumResult = 5;
        const result = (0, getLastBuffers_1.default)(buffer, maxNumResult);
        expect(result.length).toBe(3);
        expect(result.map(item => item.code)).toEqual(['A', 'C', 'B']);
    });
});
