"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const generateTicker_1 = __importDefault(require("../../generators/generateTicker"));
const sortBuffers_1 = __importDefault(require("../../../src/functions/sortBuffers"));
describe('sortBuffers', () => {
    const ticker1 = (0, generateTicker_1.default)('AAPL');
    const ticker2 = (0, generateTicker_1.default)('TSLA');
    const ticker3 = (0, generateTicker_1.default)('GOOGL');
    const ticker4 = (0, generateTicker_1.default)('AMZN');
    const ticker5 = (0, generateTicker_1.default)('NFLX');
    const ticker6 = (0, generateTicker_1.default)('FB');
    const ticker7 = (0, generateTicker_1.default)('MSFT');
    const ticker8 = (0, generateTicker_1.default)('NVDA');
    const originalBuffers = [
        ticker1,
        ticker2,
        ticker3,
        ticker4,
        ticker5,
        ticker6,
        ticker7,
        ticker8,
    ];
    const sortOrder = [
        { market: 'AAPL', korean_name: '애플', english_name: 'Apple' },
        { market: 'TSLA', korean_name: '테슬라', english_name: 'Tesla' },
        { market: 'GOOGL', korean_name: '구글', english_name: 'Alphabet Inc.' },
        { market: 'AMZN', korean_name: '아마존', english_name: 'Amazon.com, Inc.' },
        { market: 'NFLX', korean_name: '넷플릭스', english_name: 'Netflix, Inc.' },
        { market: 'FB', korean_name: '페이스북', english_name: 'Facebook, Inc.' },
        {
            market: 'MSFT',
            korean_name: '마이크로소프트',
            english_name: 'Microsoft Corporation',
        },
        {
            market: 'NVDA',
            korean_name: '엔비디아',
            english_name: 'NVIDIA Corporation',
        },
    ];
    it('should sort the buffers in the order specified by sortOrder', () => {
        const sortedBuffers = (0, sortBuffers_1.default)(originalBuffers, sortOrder);
        expect(sortedBuffers).toEqual([
            ticker1,
            ticker2,
            ticker3,
            ticker4,
            ticker5,
            ticker6,
            ticker7,
            ticker8,
        ]);
    });
    it('should return undefined if originalBuffers is empty', () => {
        const sortedBuffers = (0, sortBuffers_1.default)([], sortOrder);
        expect(sortedBuffers).toBeUndefined();
    });
    it('should return undefined if sortOrder is empty', () => {
        const sortedBuffers = (0, sortBuffers_1.default)(originalBuffers, []);
        expect(sortedBuffers).toBeUndefined();
    });
});
